Range-v3: boost::range_const_iterator< ::ranges::v3::adjacent_remove_if_view< Ts... >, ::meta::if_c<(bool)::ranges::BoundedRange< ::ranges::v3::adjacent_remove_if_view< Ts... > const >()> > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | List of all members
boost::range_const_iterator< ::ranges::v3::adjacent_remove_if_view< Ts... >, ::meta::if_c<(bool)::ranges::BoundedRange< ::ranges::v3::adjacent_remove_if_view< Ts... > const >()> > Struct Template Reference

## Public Types
using | type = ::ranges::iterator_t< ::ranges::v3::adjacent_remove_if_view< Ts... > const >